@@ -119,9 +119,10 @@ typedef struct {
 
 char const*	me;			/* executable name */
 
-bool		binary_opt   = true;
-bool		compress_opt = true;
-bool		verbose_opt  = false;
+bool		binary_opt		= true;
+bool		compress_opt		= true;
+bool		no_check_doc_opt	= false;
+bool		verbose_opt		= false;
 
 void		compress( buffer* );
 void		decode( char const *src_file_name, char const *dest_file_name );
@@ -167,7 +168,7 @@ void		write_error();
 	extern int	optind, opterr;
 
 	bool		decode_opt = false;
-	char const	opts[] = "bcdvV";	/* command line options */
+	char const	opts[] = "bcdDvV";	/* command line options */
 	int		opt;			/* option being processed */
 
 	me = strrchr( argv[0], '/' );		/* determine base name... */
@@ -191,6 +192,10 @@ void		write_error();
 				decode_opt = true;
 				break;
 
+			case 'D':
+				no_check_doc_opt = true;
+				break;
+
 			case 'v':
 				verbose_opt = true;
 				break;
@@ -359,15 +364,18 @@ void		write_error();
 
 	fin = open_src_file( src_file_name );
 
-	if ( fread( &header, DatabaseHdrSize, 1, fin ) != 1 ||
+	if ( fread( &header, DatabaseHdrSize, 1, fin ) != 1 )
+		read_error();
+	if ( !no_check_doc_opt && (
 	     strncmp( header.type,    DOC_TYPE,    sizeof header.type ) ||
 	     strncmp( header.creator, DOC_CREATOR, sizeof header.creator )
-	) {
+	) ) {
 		fprintf( stderr, "%s: %s is not a Doc file\n",
-			me, dest_file_name
+			me, src_file_name
 		);
 		exit( Exit_Not_Doc_File );
 	}
+
 	num_records = ntohs( header.recordList.numRecords ) - 1; /* w/o rec 0 */
 
 	fout = dest_file_name ? open_dest_file( dest_file_name ) : stdout;
@@ -500,7 +508,6 @@ void		write_error();
 	header.recordList.nextRecordListID	= 0;
 	header.recordList.numRecords		= htons( num_records + 1 );
 						/* +1 for rec 0 */
-
 	fseek( fin, 0, SEEK_SET );
 	if ( fwrite( &header, DatabaseHdrSize, 1, fout ) != 1 )
 		write_error();
@@ -722,7 +729,7 @@ void		write_error();
  *
  *****************************************************************************/
 
-/* replacement for strstr() which deals with 0's in the data */
+/* replacement for strstr() that deals with 0's in the data */
 Byte* mem_find( register Byte *t, int t_len, register Byte *m, int m_len ) {
 	register int i;
 	for ( i = t_len - m_len + 1; i > 0; --i, ++t )
@@ -753,13 +760,14 @@ void read_error() {
 void usage() {
 	fprintf( stderr,
 	"usage: %s [-c] [-b] [-v] document_name file.txt file.pdb\n"
-	"       %s  -d  [-b] [-v] file.pdb [file.txt]\n"
+	"       %s  -d  [-D] [-v] file.pdb [file.txt]\n"
 	"       %s  -V\n\n"
 	"options:\n"
 	"--------\n"
 	" -b: don't strip binary characters\n"
 	" -c: don't compress Doc file\n"
 	" -d: decode Doc file to text\n"
+	" -D: do not check the type/creator of the Doc file\n"
 	" -v: verbose\n"
 	" -V: print version and exit\n", me, me, me );
 	exit( Exit_Usage );
@@ -769,4 +777,3 @@ void write_error() {
 	fprintf( stderr, "%s: writing failed\n", me );
 	exit( Exit_No_Write );
 }
-
